@@ -35,6 +35,11 @@ G_BEGIN_DECLS
 #define ANJUTA_PLUGIN_MANAGER_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), ANJUTA_TYPE_PLUGIN_MANAGER, AnjutaPluginManagerClass))
 #define ANJUTA_PLUGIN_MANAGER_ERROR            (anjuta_plugin_manager_error_quark())
 
+/**
+  * AnjutaPluginManagerError:
+  * @ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY: The factory for the plugin couldn't be found
+  * @ANJUTA_PLUGIN_MANAGER_ERROR_UNKNOWN: Unknown error
+  */
 typedef enum
 {
 	ANJUTA_PLUGIN_MANAGER_MISSING_FACTORY,
@@ -92,21 +97,24 @@ GtkWidget* anjuta_plugin_manager_get_remembered_plugins_page (AnjutaPluginManage
 /* Plugin queries based on meta-data */
 /* Returns a list of plugin Descriptions */
 GList* anjuta_plugin_manager_query (AnjutaPluginManager *plugin_manager,
-									const gchar *section_name,
-									const gchar *attribute_name,
-									const gchar *attribute_value,
+									const gchar *section_names,
+									const gchar *attribute_names,
+									const gchar *attribute_values,
 									...);
+GList* anjuta_plugin_manager_list_query (AnjutaPluginManager *plugin_manager,
+										 GList *section_names,
+										 GList *attribute_names,
+										 GList *attribute_values);
 
 /* Returns the plugin description that has been selected from the list */
 AnjutaPluginDescription* anjuta_plugin_manager_select (AnjutaPluginManager *plugin_manager,
 													   gchar *title, gchar *description,
 													   GList *plugin_descriptions);
 
-/* Returns the plugin that has been selected and activated */
-GObject* anjuta_plugin_manager_select_and_activate (AnjutaPluginManager *plugin_manager,
-													gchar *title,
-													gchar *description,
-													GList *plugin_descriptions);
+
+GObject*  anjuta_plugin_manager_select_and_activate (AnjutaPluginManager *plugin_manager,
+													   gchar *title, gchar *description,
+			   GList *plugin_descriptions);
 
 void anjuta_plugin_manager_activate_plugins (AnjutaPluginManager *plugin_manager,
 											 GList *plugin_descs);
