@@ -61,10 +61,18 @@ extern void libanjuta_iface_cclosure_marshal_VOID__OBJECT_CHAR (GClosure     *cl
 /* VOID:POINTER (./libanjuta-iface-marshallers.list:10) */
 #define libanjuta_iface_cclosure_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:STRING (./libanjuta-iface-marshallers.list:11) */
+/* VOID:POINTER,BOXED (./libanjuta-iface-marshallers.list:11) */
+extern void libanjuta_iface_cclosure_marshal_VOID__POINTER_BOXED (GClosure     *closure,
+                                                                  GValue       *return_value,
+                                                                  guint         n_param_values,
+                                                                  const GValue *param_values,
+                                                                  gpointer      invocation_hint,
+                                                                  gpointer      marshal_data);
+
+/* VOID:STRING (./libanjuta-iface-marshallers.list:12) */
 #define libanjuta_iface_cclosure_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:12) */
+/* VOID:STRING,STRING (./libanjuta-iface-marshallers.list:13) */
 extern void libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                                   GValue       *return_value,
                                                                   guint         n_param_values,
@@ -72,7 +80,7 @@ extern void libanjuta_iface_cclosure_marshal_VOID__STRING_STRING (GClosure     *
                                                                   gpointer      invocation_hint,
                                                                   gpointer      marshal_data);
 
-/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:13) */
+/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:14) */
 extern void libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -80,7 +88,7 @@ extern void libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:14) */
+/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:15) */
 extern void libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
                                                                       GValue       *return_value,
                                                                       guint         n_param_values,
@@ -88,7 +96,7 @@ extern void libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure
                                                                       gpointer      invocation_hint,
                                                                       gpointer      marshal_data);
 
-/* VOID:VOID (./libanjuta-iface-marshallers.list:15) */
+/* VOID:VOID (./libanjuta-iface-marshallers.list:16) */
 #define libanjuta_iface_cclosure_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
 G_END_DECLS
