@@ -26,6 +26,7 @@ void on_save_all_activate (GtkAction *action, gpointer user_data);
 void on_close_file_activate (GtkAction *action, gpointer user_data);
 void on_reload_file_activate (GtkAction *action, gpointer user_data);
 void on_close_all_file_activate (GtkAction *action, gpointer user_data);
+void on_close_other_file_activate (GtkAction *action, gpointer user_data);
 
 void on_print_activate (GtkAction *action, gpointer user_data);
 void on_print_preview_activate (GtkAction *action, gpointer user_data);
@@ -97,9 +98,10 @@ void on_repeat_quicksearch (GtkAction *action, gpointer user_data);
 void on_next_document (GtkAction *action, gpointer user_data);
 void on_previous_document (GtkAction *action, gpointer user_data);
 
-void on_bookmark_add_activate (GtkAction *action, gpointer user_data);
+void on_bookmark_toggle_activate (GtkAction *action, gpointer user_data);
 void on_bookmark_next_activate (GtkAction *action, gpointer user_data);
 void on_bookmark_prev_activate (GtkAction *action, gpointer user_data);
 void on_bookmarks_clear_activate (GtkAction *action, gpointer user_data);
 
+void on_autocomplete_activate (GtkAction *action, gpointer user_data);
 #endif
