@@ -41,9 +41,10 @@ struct _GbfProjectModelPrivate {
 	AnjutaPmProject      *proj;
 	gulong               project_updated_handler;
 	
-	GtkTreeRowReference *root_row;
+	GtkTreeRowReference *root_group;
 	GList               *shortcuts;
 
+	gboolean default_shortcut;	   /* Add shortcut for each primary node */
 };
 
 enum {
@@ -56,8 +57,6 @@ enum {
 
 static void     gbf_project_model_class_init         (GbfProjectModelClass   *klass);
 static void     gbf_project_model_instance_init      (GbfProjectModel        *tree);
-static void     gbf_project_model_drag_source_init   (GtkTreeDragSourceIface *iface);
-static void     gbf_project_model_drag_dest_init     (GtkTreeDragDestIface   *iface);
 
 static void     load_project                         (GbfProjectModel        *model,
 						      AnjutaPmProject  *proj);
@@ -69,23 +68,6 @@ static gint     default_sort_func                    (GtkTreeModel           *mo
 						      GtkTreeIter            *iter_b,
 						      gpointer                user_data);
 
-/* DND functions */
-
-static gboolean row_draggable                        (GtkTreeDragSource      *drag_source,
-						      GtkTreePath            *path);
-
-static gboolean drag_data_delete                     (GtkTreeDragSource      *drag_source,
-						      GtkTreePath            *path);
-
-static gboolean drag_data_received                   (GtkTreeDragDest        *drag_dest,
-						      GtkTreePath            *dest,
-						      GtkSelectionData       *selection_data);
-
-static gboolean row_drop_possible                    (GtkTreeDragDest        *drag_dest,
-						      GtkTreePath            *dest_path,
-						      GtkSelectionData       *selection_data);
-
-
 static GtkTreeStoreClass *parent_class = NULL;
 
 
@@ -95,20 +77,6 @@ static GtkTreeStoreClass *parent_class = NULL;
 
 /* Type & interfaces initialization */
 
-static void
-gbf_project_model_drag_source_init (GtkTreeDragSourceIface *iface)
-{
-	iface->row_draggable = row_draggable;
-	iface->drag_data_delete = drag_data_delete;
-}
-
-static void
-gbf_project_model_drag_dest_init (GtkTreeDragDestIface *iface)
-{
-	iface->drag_data_received = drag_data_received;
-	iface->row_drop_possible = row_drop_possible;
-}
-
 static void
 gbf_project_model_class_init_trampoline (gpointer klass,
 					 gpointer data)
@@ -133,28 +101,10 @@ gbf_project_model_get_type (void)
 		    0,                  /* n_preallocs */
 		    (GInstanceInitFunc) gbf_project_model_instance_init
 		};
-		static const GInterfaceInfo drag_source_info = {
-			(GInterfaceInitFunc) gbf_project_model_drag_source_init,
-			NULL,
-			NULL
-		};
-		static const GInterfaceInfo drag_dest_info = {
-			(GInterfaceInitFunc) gbf_project_model_drag_dest_init,
-			NULL,
-			NULL
-		};
 
 		object_type = g_type_register_static (
 			GTK_TYPE_TREE_STORE, "GbfProjectModel",
 			&object_info, 0);
-
-		g_type_add_interface_static (object_type,
-					     GTK_TYPE_TREE_DRAG_SOURCE,
-					     &drag_source_info);
-
-		g_type_add_interface_static (object_type,
-					     GTK_TYPE_TREE_DRAG_DEST,
-					     &drag_dest_info);
 	}
 	return object_type;
 }
@@ -247,6 +197,7 @@ gbf_project_model_instance_init (GbfProjectModel *model)
 					 types);
 
 	model->priv = g_new0 (GbfProjectModelPrivate, 1);
+	model->priv->default_shortcut = TRUE;
 
 	/* sorting function */
 	gtk_tree_sortable_set_default_sort_func (GTK_TREE_SORTABLE (model),
@@ -259,6 +210,37 @@ gbf_project_model_instance_init (GbfProjectModel *model)
 	insert_empty_node (model);
 }
 
+GtkTreeRowReference *
+gbf_project_model_get_root (GbfProjectModel *model)
+{
+	if (model->priv->root_group == NULL)
+	{
+		GtkTreeIter iter;
+		gboolean valid;
+
+		/* Search root group */
+		for (valid = gtk_tree_model_iter_children (GTK_TREE_MODEL (model), &iter, NULL); valid; valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
+		{
+			GbfTreeData *data;
+			
+			gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
+	   			 GBF_PROJECT_MODEL_COLUMN_DATA, &data,
+		    		-1);
+			
+			if (data->type == GBF_TREE_NODE_GROUP)
+			{
+				GtkTreePath *path;
+				
+				path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
+				model->priv->root_group = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), path);
+				gtk_tree_path_free (path);
+			}
+		}
+	}
+
+	return model->priv->root_group;
+}
+
 /* Model data functions ------------ */
 
 /* Remove node without checking its shortcuts */
@@ -401,6 +383,7 @@ default_sort_func (GtkTreeModel *model,
 {
 	GbfTreeData *data_a, *data_b;
 	gint retval = 0;
+	gboolean unsorted_a, unsorted_b;
 	
 	gtk_tree_model_get (model, iter_a,
 			    GBF_PROJECT_MODEL_COLUMN_DATA, &data_a,
@@ -409,7 +392,9 @@ default_sort_func (GtkTreeModel *model,
 			    GBF_PROJECT_MODEL_COLUMN_DATA, &data_b,
 			    -1);
 
-	if (data_a->is_shortcut && data_b->is_shortcut) {
+	unsorted_a = (data_a->type == GBF_TREE_NODE_SHORTCUT) || (data_a->type == GBF_TREE_NODE_UNKNOWN) || (data_a->is_shortcut);
+	unsorted_b = (data_b->type == GBF_TREE_NODE_SHORTCUT) || (data_b->type == GBF_TREE_NODE_UNKNOWN) || (data_b->is_shortcut);
+	if (unsorted_a && unsorted_b) {
 		GtkTreeIter iter;
 		gboolean valid;
 		
@@ -436,10 +421,10 @@ default_sort_func (GtkTreeModel *model,
 			}
 		}
 		
-	} else if (data_a->is_shortcut && !data_b->is_shortcut) {
+	} else if (unsorted_a && !unsorted_b) {
 		retval = -1;
 	 
-	} else if (!data_a->is_shortcut && data_b->is_shortcut) {
+	} else if (!unsorted_a && unsorted_b) {
 		retval = 1;
 	 
 	} else if (data_a->type == data_b->type) {
@@ -455,8 +440,8 @@ default_sort_func (GtkTreeModel *model,
 }
 
 
-static void 
-add_source (GbfProjectModel    	      *model,
+void
+gbf_project_model_add_source (GbfProjectModel    	      *model,
 	    AnjutaProjectNode *source,
 	    GtkTreeIter               *parent)
 {
@@ -473,60 +458,98 @@ add_source (GbfProjectModel    	      *model,
 			    -1);
 }
 
-static void 
-add_target_shortcut (GbfProjectModel *model,
+void 
+gbf_project_model_add_target_shortcut (GbfProjectModel *model,
                      GtkTreeIter     *shortcut,
 		     GbfTreeData     *target,
-		     GtkTreePath     *before_path)
+		     GtkTreePath     *before_path,
+                     gboolean	     *expanded)
 {
 	AnjutaProjectNode *node;
 	GtkTreeIter iter, sibling;
 	GtkTreePath *root_path;
 	GbfTreeData *data;
 	AnjutaProjectNode *parent;
+	gboolean valid = FALSE;
 	
 	if (!target)
 		return;
 
-	root_path = gtk_tree_row_reference_get_path (model->priv->root_row);
-	/* check before_path */
-	if (!before_path ||
-	    gtk_tree_path_get_depth (before_path) > 1 ||
-	    gtk_tree_path_compare (before_path, root_path) > 0) {
-		before_path = root_path;
-	}
-		
-	/* get the tree iter for the row before which to insert the shortcut */
-	if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &sibling, before_path)) {
-		gtk_tree_path_free (root_path);
-		return;
-	}
+	if (expanded != NULL) *expanded = FALSE;
 
-	if (target->type != GBF_TREE_NODE_SHORTCUT)
+	root_path = gtk_tree_row_reference_get_path (gbf_project_model_get_root (model));
+	if ((before_path == NULL) && (target->type != GBF_TREE_NODE_SHORTCUT))
 	{
-		data = gbf_tree_data_new_shortcut (target);
+		/* Check is a proxy node is not already existing. It is used to
+		 * save the shortcut order */
+
+		for (valid = gtk_tree_model_iter_children (GTK_TREE_MODEL (model), &iter, NULL);
+			valid;
+			valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
+		{
+			GbfTreeData *data;
+
+			/* Look for current node */
+			gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
+				GBF_PROJECT_MODEL_COLUMN_DATA, &data,
+				-1);
+
+			if (((data->type == GBF_TREE_NODE_UNKNOWN) || (data->type == GBF_TREE_NODE_SHORTCUT)) && (g_strcmp0 (target->name, data->name) == 0))
+			{
+				/* Find already existing node and replace it */
+				if (expanded != NULL) *expanded = data->expanded;
+				gbf_tree_data_free (data);
+				
+				data = gbf_tree_data_new_shortcut (target);
+				gtk_tree_store_set (GTK_TREE_STORE (model), &iter, 
+				    GBF_PROJECT_MODEL_COLUMN_DATA, data,
+				    -1);
+				break;
+			}
+		}
 	}
-	else
+	if (!valid)
 	{
-		data = target;
+		/* check before_path */
+		if ((before_path == NULL) ||
+		    gtk_tree_path_get_depth (before_path) > 1 ||
+		    gtk_tree_path_compare (before_path, root_path) > 0)
+		{
+			before_path = root_path;
+		}
+		
+		/* get the tree iter for the row before which to insert the shortcut */
+		if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &sibling, before_path)) {
+			gtk_tree_path_free (root_path);
+			return;
+		}
+
+		if (target->type != GBF_TREE_NODE_SHORTCUT)
+		{
+			data = gbf_tree_data_new_shortcut (target);
+		}
+		else
+		{
+			data = target;
+		}
+		gtk_tree_store_insert_before (GTK_TREE_STORE (model), &iter, NULL, &sibling);
+		gtk_tree_store_set (GTK_TREE_STORE (model), &iter, 
+				    GBF_PROJECT_MODEL_COLUMN_DATA, data,
+				    -1);
 	}
-	gtk_tree_store_insert_before (GTK_TREE_STORE (model), &iter, NULL, &sibling);
-	gtk_tree_store_set (GTK_TREE_STORE (model), &iter, 
-			    GBF_PROJECT_MODEL_COLUMN_DATA, data,
-			    -1);
 	
 	/* add sources */
 	parent = gbf_tree_data_get_node (target);
 	for (node = anjuta_project_node_first_child (parent); node; node = anjuta_project_node_next_sibling (node))
-		add_source (model, node, &iter);
+		gbf_project_model_add_source (model, node, &iter);
 
 	gtk_tree_path_free (root_path);
 
 	if (shortcut) *shortcut = iter;
 }
 
-static void 
-move_target_shortcut (GbfProjectModel *model,
+void 
+gbf_project_model_move_target_shortcut (GbfProjectModel *model,
 		     GtkTreeIter     *iter,
     		     GbfTreeData     *shortcut,
 		     GtkTreePath     *before_path)
@@ -540,7 +563,7 @@ move_target_shortcut (GbfProjectModel *model,
 	if (!shortcut)
 		return;
 
-	root_path = gtk_tree_row_reference_get_path (model->priv->root_row);
+	root_path = gtk_tree_row_reference_get_path (gbf_project_model_get_root (model));
 	
 	/* check before_path */
 	if (!before_path ||
@@ -576,7 +599,7 @@ move_target_shortcut (GbfProjectModel *model,
 		/* add sources */
 		parent = gbf_tree_data_get_node (shortcut->shortcut);
 		for (node = anjuta_project_node_first_child (parent); node; node = anjuta_project_node_next_sibling (node))
-			add_source (model, node, iter);
+			gbf_project_model_add_source (model, node, iter);
 	}
 
 	gtk_tree_path_free (src_path);
@@ -584,8 +607,8 @@ move_target_shortcut (GbfProjectModel *model,
 
 }
 
-static void 
-add_package (GbfProjectModel    	      *model,
+void
+gbf_project_model_add_package (GbfProjectModel    	      *model,
 	    AnjutaProjectNode *package,
 	    GtkTreeIter               *parent)
 {
@@ -605,12 +628,12 @@ add_package (GbfProjectModel    	      *model,
 	/* ... and sources */
 	for (node = anjuta_project_node_first_child (package); node; node = anjuta_project_node_next_sibling (node))
 	{
-		add_source (model, node, &iter);
+		gbf_project_model_add_source (model, node, &iter);
 	}
 }
 
-static void 
-add_module (GbfProjectModel 		*model,
+void
+gbf_project_model_add_module (GbfProjectModel 		*model,
 	    AnjutaProjectNode   *module,
 	    GtkTreeIter     	        *parent)
 {
@@ -630,12 +653,12 @@ add_module (GbfProjectModel 		*model,
 	/* add package */
 	for (l = anjuta_project_node_first_child (module); l; l = anjuta_project_node_next_sibling (l))
 	{
-		add_package (model, l, &iter);
+		gbf_project_model_add_package (model, l, &iter);
 	}
 }
 
-static void 
-add_target (GbfProjectModel 		*model,
+void
+gbf_project_model_add_target (GbfProjectModel 		*model,
 	    AnjutaProjectNode   *target,
 	    GtkTreeIter     	        *parent)
 {
@@ -655,22 +678,18 @@ add_target (GbfProjectModel 		*model,
 	/* add sources */
 	for (l = anjuta_project_node_first_child (target); l; l = anjuta_project_node_next_sibling (l))
 	{
-		add_source (model, l, &iter);
+		gbf_project_model_add_source (model, l, &iter);
 	}
 
-	/* add a shortcut to the target if the target's type is a primary */
-	/* FIXME: this shouldn't be here.  We would rather provide a
-	 * set of public functions to add/remove shortcuts to save
-	 * this information in the project metadata (when that's
-	 * implemented) */
-	/*if (anjuta_project_node_get_full_type (target) & ANJUTA_PROJECT_PRIMARY)
+	/* Add shortcut if needed */
+	if ((data != NULL) && model->priv->default_shortcut && (anjuta_project_node_get_full_type (target) & ANJUTA_PROJECT_PRIMARY))
 	{
-		add_target_shortcut (model, NULL, data, NULL);
-	}*/
+		gbf_project_model_add_target_shortcut (model, NULL, data, NULL, NULL);
+	}
 }
 
-static void 
-add_target_group (GbfProjectModel 	*model,
+void
+gbf_project_model_add_target_group (GbfProjectModel 	*model,
 		  AnjutaProjectNode	*group,
 		  GtkTreeIter     	*parent)
 {
@@ -687,31 +706,21 @@ add_target_group (GbfProjectModel 	*model,
 			    GBF_PROJECT_MODEL_COLUMN_DATA, data,
 			    -1);
 
-	/* create root reference */
-	if (parent == NULL) {
-		GtkTreePath *root_path;
-
-		root_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
-		model->priv->root_row = gtk_tree_row_reference_new (
-			GTK_TREE_MODEL (model), root_path);
-		gtk_tree_path_free (root_path);
-	}
-
 	/* add groups ... */
 	for (node = anjuta_project_node_first_child (group); node; node = anjuta_project_node_next_sibling (node))
-		add_target_group (model, node, &iter);
+		gbf_project_model_add_target_group (model, node, &iter);
 	
 	/* ... and targets */
 	for (node = anjuta_project_node_first_child (group); node; node = anjuta_project_node_next_sibling (node))
-		add_target (model, node, &iter);
+		gbf_project_model_add_target (model, node, &iter);
 	
 	/* ... and sources */
 	for (node = anjuta_project_node_first_child (group); node; node = anjuta_project_node_next_sibling (node))
-		add_source (model, node, &iter);
+		gbf_project_model_add_source (model, node, &iter);
 }
 
-static void
-add_root (GbfProjectModel 	*model,
+void
+gbf_project_model_add_root (GbfProjectModel 	*model,
     AnjutaProjectNode	*root,
     GtkTreeIter     	*parent)
 {
@@ -722,16 +731,16 @@ add_root (GbfProjectModel 	*model,
 
 	/* create root reference */
 	/*root_path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
-	model->priv->root_row = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), root_path);
+	model->priv->root_group = gtk_tree_row_reference_new (GTK_TREE_MODEL (model), root_path);
 	gtk_tree_path_free (root_path);*/
 
 	/* add groups ... */
 	for (node = anjuta_project_node_first_child (root); node; node = anjuta_project_node_next_sibling (node))
-		add_target_group (model, node, NULL);
+		gbf_project_model_add_target_group (model, node, NULL);
 	
 	/* ... and module */
 	for (node = anjuta_project_node_first_child (root); node; node = anjuta_project_node_next_sibling (node))
-		add_module (model, node, NULL);
+		gbf_project_model_add_module (model, node, NULL);
 }
 
 static void
@@ -740,18 +749,7 @@ load_project (GbfProjectModel *model, AnjutaPmProject *proj)
 	model->priv->proj = proj;
 	g_object_ref (proj);
 
-	/* to get rid of the empty node */
-	gbf_project_model_clear (model);
-
-	add_root (model, anjuta_pm_project_get_root (proj), NULL);
-	//add_target_group (model, anjuta_pm_project_get_root (proj), NULL);
-
-	//model->priv->project_updated_handler =
-	//	g_signal_connect (anjuta_pm_project_get_project (model->priv->proj), "project-updated",
-	//			  (GCallback) project_updated_cb, model);
-	//model->priv->project_updated_handler =
-	//	g_signal_connect (anjuta_pm_project_get_project (model->priv->proj), "project-updated",
-	//			  (GCallback) project_updated_cb, model);
+	gbf_project_model_add_root (model, anjuta_pm_project_get_root (proj), NULL);
 }
 
 static void 
@@ -772,8 +770,8 @@ static void
 unload_project (GbfProjectModel *model)
 {
 	if (model->priv->proj) {
-		gtk_tree_row_reference_free (model->priv->root_row);
-		model->priv->root_row = NULL;
+		gtk_tree_row_reference_free (model->priv->root_group);
+		model->priv->root_group = NULL;
 
 		gbf_project_model_clear (model);
 
@@ -823,121 +821,6 @@ recursive_find_tree_data (GtkTreeModel  *model,
 	return retval;
 }
 
-static void
-gbf_project_model_update_shortcut (GbfProjectModel *model, AnjutaProjectNode *parent)
-{
-	GtkTreeIter child;
-	gboolean valid;
-
-	/* Get all root node */
-	valid = gtk_tree_model_iter_children (GTK_TREE_MODEL (model), &child, NULL);
-
-	while (valid)
-	{
-		GbfTreeData *data;
-		AnjutaProjectNode* old_node = NULL;
-
-		gtk_tree_model_get (GTK_TREE_MODEL (model), &child,
-	  			 GBF_PROJECT_MODEL_COLUMN_DATA, &data,
-	    			-1);
-
-		/* Shortcuts are always at the beginning */
-		if (data->type != GBF_TREE_NODE_SHORTCUT) break;
-
-		old_node = gbf_tree_data_get_node (data);
-		if (old_node == parent)
-		{
-			/* check children */
-			gbf_project_model_update_tree (model, parent, &child);
-		}
-		valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &child);
-	}	
-}
-
-void
-gbf_project_model_update_tree (GbfProjectModel *model, AnjutaProjectNode *parent, GtkTreeIter *iter)
-{
-	GtkTreeIter child;
-	GList *node;
-	GList *nodes;
-
-	/* Get all new nodes */
-	nodes = gbf_project_util_all_child (parent, ANJUTA_PROJECT_UNKNOWN);
-
-	/* walk the tree nodes */
-	if (gtk_tree_model_iter_children (GTK_TREE_MODEL (model), &child, iter))
-	{
-		gboolean valid = TRUE;
-		
-		while (valid) {
-			GbfTreeData *data = NULL;
-			AnjutaProjectNode* data_node = NULL;
-
-			/* Look for current node */
-			gtk_tree_model_get (GTK_TREE_MODEL (model), &child,
-				GBF_PROJECT_MODEL_COLUMN_DATA, &data,
-				-1);
-
-			data_node = gbf_tree_data_get_node (data);
-			
-			/* Skip shortcuts */
-			if (data->type == GBF_TREE_NODE_SHORTCUT)
-			{	
-				valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &child);
-				continue;
-			}
-
-			node = g_list_find (nodes, data_node);
-			if (node != NULL)
-			{
-				/* Node already exist, remove it from the list */
-				nodes = g_list_delete_link (nodes, node);
-
-				/* Update shortcut */
-				gbf_project_model_update_shortcut (model, data_node);
-				                                   
-				/* update recursively */
-				gbf_project_model_update_tree (model, data_node, &child);
-
-				valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &child);
-			}
-			else
-			{
-				/* Node has been deleted */
-				valid = gbf_project_model_remove (model, &child);
-			}
-		}
-	}
-
-	/* add the remaining sources, targets and groups */
-	for (node = nodes; node; node = node->next)
-	{
-		switch (anjuta_project_node_get_node_type (node->data))
-		{
-		case ANJUTA_PROJECT_GROUP:
-			add_target_group (model, node->data, iter);
-			break;
-		case ANJUTA_PROJECT_TARGET:
-			add_target (model, node->data, iter);
-			break;
-		case ANJUTA_PROJECT_SOURCE:
-			add_source (model, node->data, iter);
-			break;
-		case ANJUTA_PROJECT_MODULE:
-			add_module (model, node->data, iter);
-			break;
-		case ANJUTA_PROJECT_PACKAGE:
-			add_package (model, node->data, iter);
-			break;
-		case ANJUTA_PROJECT_ROOT:
-			add_root (model, node->data, iter);
-			break;
-		default:
-			break;
-		}
-	}
-}
-
 gboolean 
 gbf_project_model_find_tree_data (GbfProjectModel 	*model,
 			          GtkTreeIter     	*iter,
@@ -1030,6 +913,34 @@ gbf_project_model_find_node (GbfProjectModel 	*model,
 	return valid;
 }
 
+/* Can return shortcut node if exist */
+gboolean 
+gbf_project_model_find_child_name (GbfProjectModel 	*model,
+	GtkTreeIter		*found,
+	GtkTreeIter		*parent,
+        const gchar		*name)                        
+{
+	GtkTreeIter iter;
+	gboolean valid;
+
+	/* Search for direct children only */
+	for (valid = gtk_tree_model_iter_children (GTK_TREE_MODEL (model), &iter, parent); valid == TRUE; valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (model), &iter))
+	{
+		GbfTreeData *data;
+		
+		gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
+		    GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
+
+		if (gbf_tree_data_equal_name (data, name))
+		{
+			*found = iter;
+			break;
+		}
+	}
+
+	return valid;
+}
+
 GbfProjectModel *
 gbf_project_model_new (AnjutaPmProject *project)
 {
@@ -1045,7 +956,7 @@ gbf_project_model_set_project (GbfProjectModel *model, AnjutaPmProject *project)
 	
 	if (model->priv->proj != project)
 	{
-		unload_project (model);
+		//unload_project (model);
 
 		/* project can be NULL */
 		if (project)
@@ -1068,8 +979,8 @@ gbf_project_model_get_project_root (GbfProjectModel *model)
 	
 	g_return_val_if_fail (GBF_IS_PROJECT_MODEL (model), NULL);
 
-	if (model->priv->root_row)
-		path = gtk_tree_row_reference_get_path (model->priv->root_row);
+	if (gbf_project_model_get_root (model))
+		path = gtk_tree_row_reference_get_path (model->priv->root_group);
 	
 	return path;
 }
@@ -1096,142 +1007,13 @@ gbf_project_model_add_shortcut (GbfProjectModel *model,
 	GtkTreePath *path;
 
 	path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), before);
-	add_target_shortcut (model, iter, target, path);
+	gbf_project_model_add_target_shortcut (model, iter, target, path, NULL);
 	gtk_tree_path_free (path);
 }
 
-/* DND stuff ------------- */
-
-static gboolean
-row_draggable (GtkTreeDragSource *drag_source, GtkTreePath *path)
+void
+gbf_project_model_set_default_shortcut (GbfProjectModel *model,
+                                        gboolean enable)
 {
-	GtkTreeIter iter;
-	GbfTreeData *data;
-	gboolean retval = FALSE;
-	
-	if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (drag_source), &iter, path))
-		return FALSE;
-
-	gtk_tree_model_get (GTK_TREE_MODEL (drag_source), &iter,
-			    GBF_PROJECT_MODEL_COLUMN_DATA, &data,
-			    -1);
-
-	if (data->is_shortcut) {
-		/* shortcuts can be moved */
-		retval = TRUE;
-
-	} else if (data->type == GBF_TREE_NODE_TARGET) {
-		/* don't allow duplicate shortcuts */
-		if (data->shortcut == NULL)
-			retval = TRUE;
-	}
-
-	return retval;
-}
-
-static gboolean 
-drag_data_delete (GtkTreeDragSource *drag_source, GtkTreePath *path)
-{
-	return FALSE;
-}
-
-static gboolean
-drag_data_received (GtkTreeDragDest  *drag_dest,
-		    GtkTreePath      *dest,
-		    GtkSelectionData *selection_data)
-{
-	GtkTreeModel *src_model = NULL;
-	GtkTreePath *src_path = NULL;
-	gboolean retval = FALSE;
-
-	g_return_val_if_fail (GBF_IS_PROJECT_MODEL (drag_dest), FALSE);
-
-	if (gtk_tree_get_row_drag_data (selection_data,
-					&src_model,
-					&src_path) &&
-	    src_model == GTK_TREE_MODEL (drag_dest)) {
-
-		GtkTreeIter iter;
-		GbfTreeData *data = NULL;
-		
-		if (gtk_tree_model_get_iter (src_model, &iter, src_path)) {
-			gtk_tree_model_get (src_model, &iter,
-					    GBF_PROJECT_MODEL_COLUMN_DATA, &data,
-					    -1);
-			if (data != NULL)
-			{
-				if (data->type == GBF_TREE_NODE_SHORTCUT)
-				{
-					move_target_shortcut (GBF_PROJECT_MODEL (drag_dest),
-					    		&iter, data, dest);
-				}
-				else
-				{
-					add_target_shortcut (GBF_PROJECT_MODEL (drag_dest),
-						     	NULL, data, dest);
-				}
-				retval = TRUE;
-			}
-		}
-	}
-
-	if (src_path)
-		gtk_tree_path_free (src_path);
-
-	return retval;
-}
-
-static gboolean
-row_drop_possible (GtkTreeDragDest  *drag_dest,
-		   GtkTreePath      *dest_path,
-		   GtkSelectionData *selection_data)
-{
-	GtkTreeModel *src_model;
-	GtkTreePath *src_path;
-	GbfProjectModel *model;
-	GtkTreeIter iter;
-	gboolean retval = FALSE;
-  
-	g_return_val_if_fail (GBF_IS_PROJECT_MODEL (drag_dest), FALSE);
-
-	model = GBF_PROJECT_MODEL (drag_dest);
-
-	if (!gtk_tree_get_row_drag_data (selection_data,
-					 &src_model,
-					 &src_path))
-		return FALSE;
-	
-		
-	if (gtk_tree_model_get_iter (src_model, &iter, src_path))
-	{
-		GbfTreeData *data = NULL;
-		
-		gtk_tree_model_get (src_model, &iter,
-		    GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
-
-		if (data != NULL)
-		{
-			/* can only drag to ourselves and only new toplevel nodes will
-			 * be created */
-			if (src_model == GTK_TREE_MODEL (drag_dest) &&
-	    			gtk_tree_path_get_depth (dest_path) == 1)
-			{
-				if (data->type == GBF_TREE_NODE_SHORTCUT)
-				{
-					retval = TRUE;
-				}
-				else
-				{
-					GtkTreePath *root_path;
-					
-					root_path = gtk_tree_row_reference_get_path (model->priv->root_row);
-					retval = gtk_tree_path_compare (dest_path, root_path) <= 0;
-					gtk_tree_path_free (root_path);
-				}
-			}
-		}
-	}
-	gtk_tree_path_free (src_path);
-
-	return retval;
+	model->priv->default_shortcut = enable;
 }
