@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef __PROJECT_WIZARD_PLUGIN__
@@ -25,7 +25,7 @@
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
 #include <libanjuta/anjuta-preferences.h>
 
-extern GType npw_plugin_get_type (AnjutaGluePlugin *plugin);
+extern GType npw_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_NPW         (npw_plugin_get_type (NULL))
 #define ANJUTA_PLUGIN_NPW(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_NPW, NPWPlugin))
 #define ANJUTA_PLUGIN_NPW_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_NPW, NPWPluginClass))
@@ -48,8 +48,10 @@ struct _NPWPluginClass {
 	AnjutaPluginClass parent_class;
 };
 
-IAnjutaMessageView* npw_plugin_create_view (NPWPlugin* this);
-void npw_plugin_append_view (NPWPlugin* this, const gchar* text);
-void npw_plugin_print_view (NPWPlugin* this, IAnjutaMessageViewType type, const gchar* summary, const gchar* details);
+IAnjutaMessageView* npw_plugin_create_view (NPWPlugin* plugin);
+void npw_plugin_append_view (NPWPlugin* plugin, const gchar* text);
+void npw_plugin_print_view (NPWPlugin* plugin, IAnjutaMessageViewType type, const gchar* summary, const gchar* details);
+
+gboolean npw_plugin_show_wizard (NPWPlugin *plugin, const gchar *template_dir);
 
 #endif
