@@ -46,7 +46,6 @@ typedef struct _SymbolDBPluginClass SymbolDBPluginClass;
 
 
 #include "symbol-db-system.h"
-#include "symbol-db-prefs.h"
 #include "symbol-db-query.h"
 
 /* default value for ctags executable. User must have it installed. This is a 
@@ -66,6 +65,9 @@ struct _SymbolDBPlugin {
 	GtkActionGroup *popup_action_group;
 	GtkActionGroup *menu_action_group;	
 	gint merge_id;
+
+	/* preferences */
+	GtkBuilder *prefs_bxml;
 	
 	/* editor monitor */
 	guint buf_update_timeout_id;
@@ -83,6 +85,7 @@ struct _SymbolDBPlugin {
 	gchar *project_root_uri;
 	gchar *project_root_dir;
 	gchar *project_opened;
+	gboolean needs_sources_scan;
 	
 	/* Symbol's engine connection to database. Instance for local project */
 	SymbolDBEngine *sdbe_project;
@@ -93,9 +96,6 @@ struct _SymbolDBPlugin {
 	/* system's population object */
 	SymbolDBSystem *sdbs;
 	
-	/* preferences object */
-	SymbolDBPrefs *sdbp;
-	
 	GtkWidget *dbv_main;					/* symbol main window [gtk_box] */
 	GtkWidget *dbv_notebook;          		/* main notebook */
 	GtkWidget *dbv_hbox;					/* hbox for notebook buttons */
@@ -127,7 +127,7 @@ struct _SymbolDBPlugin {
 	gint files_count_system;
 	gint files_count_system_done;
 	gchar *current_scanned_package;
-	GList *session_packages;
+	GHashTable *session_packages;
 
 	IAnjutaSymbolQuery *search_query;
 	
