@@ -24,6 +24,7 @@
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/anjuta-save-prompt.h>
 #include <libanjuta/anjuta-plugin-manager.h>
+#include <libanjuta/resources.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 
@@ -37,6 +38,8 @@
 #define DEFAULT_PROFILE "file://"PACKAGE_DATA_DIR"/profiles/default.profile"
 #define USER_PROFILE_NAME "user"
 
+#define ANJUTA_PIXMAP_SPLASH_SCREEN       "anjuta_splash.png"
+
 static gchar *system_restore_session = NULL;
 
 static gboolean
@@ -47,12 +50,12 @@ on_anjuta_delete_event (AnjutaApp *app, GdkEvent *event, gpointer data)
 	AnjutaProfile *current_profile;
 	AnjutaSavePrompt *save_prompt;
 	gchar *remembered_plugins;
-	
+
 	DEBUG_PRINT ("%s", "AnjutaApp delete event");
-	
+
 	plugin_manager = anjuta_shell_get_plugin_manager (ANJUTA_SHELL (app), NULL);
 	profile_manager = anjuta_shell_get_profile_manager (ANJUTA_SHELL (app), NULL);
-	
+
 	/* Save remembered plugins */
 	remembered_plugins =
 		anjuta_plugin_manager_get_remembered_plugins (plugin_manager);
@@ -60,7 +63,7 @@ on_anjuta_delete_event (AnjutaApp *app, GdkEvent *event, gpointer data)
 	                       ANJUTA_REMEMBERED_PLUGINS,
 	                       remembered_plugins);
 	g_free (remembered_plugins);
-	
+
 	/* Check for unsaved data */
 	save_prompt = anjuta_save_prompt_new (GTK_WINDOW (app));
 	anjuta_shell_save_prompt (ANJUTA_SHELL (app), save_prompt, NULL);
@@ -89,7 +92,7 @@ on_anjuta_delete_event (AnjutaApp *app, GdkEvent *event, gpointer data)
 			g_main_context_iteration (NULL, TRUE);
 		}
 	}
-	
+
 	/* If current active profile is "user", save current session as
 	 * default session
 	 */
@@ -101,11 +104,11 @@ on_anjuta_delete_event (AnjutaApp *app, GdkEvent *event, gpointer data)
 		anjuta_shell_session_save (ANJUTA_SHELL (app), session_dir, NULL);
 		g_free (session_dir);
 	}
-	
+
 	anjuta_shell_notify_exit (ANJUTA_SHELL (app), NULL);
-	
+
 	gtk_widget_destroy (GTK_WIDGET (save_prompt));
-	
+
 	/* Shutdown */
 	if (g_object_get_data (G_OBJECT (app), "__proper_shutdown"))
 	{
@@ -120,7 +123,7 @@ static void
 on_anjuta_destroy (GtkWidget * w, gpointer data)
 {
 	DEBUG_PRINT ("%s", "AnjutaApp destroy event");
-	
+
 	gtk_widget_hide (w);
 	gtk_main_quit ();
 }
@@ -131,13 +134,13 @@ on_profile_scoped (AnjutaProfileManager *profile_manager,
 {
 	gchar *session_dir;
 	static gboolean first_time = TRUE;
-	
+
 	DEBUG_PRINT ("Profile scoped: %s", anjuta_profile_get_name (profile));
 	if (strcmp (anjuta_profile_get_name (profile), USER_PROFILE_NAME) != 0)
 		return;
-	
+
 	DEBUG_PRINT ("%s", "User profile loaded; Restoring user session");
-	
+
 	/* If profile scoped to "user", restore user session */
 	if (system_restore_session)
 	{
@@ -148,7 +151,7 @@ on_profile_scoped (AnjutaProfileManager *profile_manager,
 	{
 		session_dir = USER_SESSION_PATH_NEW;
 	}
-	
+
 	if (first_time)
 	{
 		first_time = FALSE;
@@ -163,7 +166,7 @@ on_profile_scoped (AnjutaProfileManager *profile_manager,
 		anjuta_session_sync (session);
 		g_object_unref (session);
 	}
-	
+
 	/* Restore session */
 	anjuta_shell_session_load (ANJUTA_SHELL (app), session_dir, NULL);
 	g_free (session_dir);
@@ -174,16 +177,16 @@ on_profile_descoped (AnjutaProfileManager *profile_manager,
 					 AnjutaProfile *profile, AnjutaApp *app)
 {
 	gchar *session_dir;
-	
+
 	DEBUG_PRINT ("Profile descoped: %s", anjuta_profile_get_name (profile));
 	if (strcmp (anjuta_profile_get_name (profile), USER_PROFILE_NAME) != 0)
 		return;
-	
+
 	DEBUG_PRINT ("%s", "User profile descoped; Saving user session");
-	
+
 	/* If profile descoped from is "user", save user session */
 	session_dir = USER_SESSION_PATH_NEW;
-	
+
 	/* Save current session */
 	anjuta_shell_session_save (ANJUTA_SHELL (app), session_dir, NULL);
 	g_free (session_dir);
@@ -198,12 +201,12 @@ extract_project_from_session (const gchar* session_dir)
 	AnjutaSession *session;
 	GList *node, *files;
 	gchar *project_uri = NULL;
-	
+
 	session = anjuta_session_new (session_dir);
-	
+
 	files = anjuta_session_get_string_list (session, "File Loader", "Files");
 	g_object_unref (session);
-	
+
 	/* Find project file */
 	node = files;
 	for (node = files; node != NULL; node = g_list_next (node))
@@ -223,15 +226,14 @@ extract_project_from_session (const gchar* session_dir)
 		}
 	}
 	g_list_free (files);
-	
+
 	return project_uri;
 }
 
 /* FIXME: Clean this mess */
 AnjutaApp*
-anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
+create_window (GFile **files, int n_files, gboolean no_splash,
 			gboolean no_session, gboolean no_files,
-			const gchar *im_file,
 			gboolean proper_shutdown, const gchar *geometry)
 {
 	AnjutaPluginManager *plugin_manager;
@@ -244,15 +246,27 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 	gchar *project_uri = NULL;
 	gchar *template_uri = NULL;
 	gchar *profile_name = NULL;
+	gchar *im_file = NULL;
 	GError *error = NULL;
-	
+
 	/* Initialize application */
 	app = ANJUTA_APP (anjuta_app_new ());
 	status = anjuta_shell_get_status (ANJUTA_SHELL (app), NULL);
 	anjuta_status_progress_add_ticks (status, 1);
+
+	/* Initialize application */
+	im_file = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_SPLASH_SCREEN);
 	
+	gtk_window_set_role (GTK_WINDOW (app), "anjuta-app");
+	gtk_window_set_auto_startup_notification(TRUE);
+	gtk_window_set_default_icon_name ("anjuta");
+	gtk_window_set_auto_startup_notification(FALSE);
+
 	if (im_file)
+	{
 		anjuta_status_set_splash (status, im_file, 100);
+		g_free (im_file);
+	}
 	if (no_splash)
 		anjuta_status_disable_splash (status, no_splash);
 
@@ -268,7 +282,7 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 													   NULL);
 	profile_manager = anjuta_shell_get_profile_manager (ANJUTA_SHELL (app),
 														NULL);
-	
+
 	/* Restore remembered plugins */
 	remembered_plugins =
 		g_settings_get_string (app->settings, ANJUTA_REMEMBERED_PLUGINS);
@@ -276,7 +290,7 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 		anjuta_plugin_manager_set_remembered_plugins (plugin_manager,
 													  remembered_plugins);
 	g_free (remembered_plugins);
-	
+
 	/* Prepare profile */
 	profile = anjuta_profile_new (USER_PROFILE_NAME, plugin_manager);
 	session_profile = g_file_new_for_uri (DEFAULT_PROFILE);
@@ -289,7 +303,7 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 		error = NULL;
 	}
 	g_object_unref (session_profile);
-	
+
 	/* Load user session profile */
 	profile_name = g_path_get_basename (DEFAULT_PROFILE);
 	session_profile = anjuta_util_get_user_cache_file (profile_name, NULL);
@@ -304,10 +318,10 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 			error = NULL;
 		}
 	}
-	anjuta_profile_set_sync_file (profile, session_profile); 
+	anjuta_profile_set_sync_file (profile, session_profile);
 	g_object_unref (session_profile);
 	g_free (profile_name);
-	
+
 	/* Load profile */
 	anjuta_profile_manager_freeze (profile_manager);
 	anjuta_profile_manager_push (profile_manager, profile, &error);
@@ -317,43 +331,46 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 		g_error_free (error);
 		error = NULL;
 	}
-	
+
 	if (files || geometry)
-	{                 
+	{
 		gchar *session_dir;
 		AnjutaSession *session;
-		gchar **node;
+		gint i;
 		GList *files_load = NULL;
-		
+
 		/* Reset default session */
 		session_dir = USER_SESSION_PATH_NEW;
-		
+
 		project_uri = extract_project_from_session (session_dir);
 		template_uri = NULL;
-		
+
 		session = anjuta_session_new (session_dir);
 		anjuta_session_clear (session);
 		if (geometry)
 			anjuta_session_set_string (session, "Anjuta", "Geometry",
 									   geometry);
-		
+
 		/* Identify non-project files and set them for loading in session */
-		for (node = files; *node != NULL; node++)
+		for (i = 0; i < n_files; i++)
 		{
-			if (anjuta_util_is_project_file (*node))
+			gchar* file = g_file_get_path (files[i]);
+			if (!file)
+				continue;
+			if (anjuta_util_is_project_file (file))
 			{
 				/* Pick up the first project file for loading later */
 				g_free (project_uri);
-				project_uri = g_strdup (*node);
+				project_uri = g_strdup (file);
 			}
-			else if (anjuta_util_is_template_file (*node))
+			else if (anjuta_util_is_template_file (file))
 			{
 				g_free (template_uri);
-				template_uri = g_strdup (*node);
+				template_uri = g_strdup (file);
 			}
 			else
 			{
-				files_load = g_list_prepend (files_load, *node);
+				files_load = g_list_prepend (files_load, g_strdup (file));
 			}
 		}
 		if (files_load)
@@ -371,10 +388,10 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 	{
 		gchar *session_dir;
 		AnjutaSession *session;
-		
+
 		/* Load user session */
 		session_dir = USER_SESSION_PATH_NEW;
-		
+
 		/* If preferences is set to not load last session, clear it */
 		if (no_session ||
 			g_settings_get_boolean (app->settings,
@@ -403,7 +420,7 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 		}
 		g_free (session_dir);
 	}
-	
+
 	/* Prepare for session save and load on profile change */
 	g_signal_connect (profile_manager, "profile-scoped",
 					  G_CALLBACK (on_profile_scoped), app);
@@ -419,7 +436,7 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 	}
 	g_free (project_uri);
 	anjuta_profile_manager_thaw (profile_manager, &error);
-	
+
 	if (error)
 	{
 		anjuta_util_dialog_error (GTK_WINDOW (app), "%s", error->message);
@@ -428,10 +445,10 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 	}
 	g_signal_connect (profile_manager, "profile-descoped",
 					  G_CALLBACK (on_profile_descoped), app);
-	
+
 	anjuta_status_progress_tick (status, NULL, _("Loaded Session…"));
 	anjuta_status_disable_splash (status, TRUE);
-	
+
 	/* Load template file */
 	if (template_uri != NULL)
 	{
@@ -443,6 +460,78 @@ anjuta_new (gchar *prog_name, gchar **files, gboolean no_splash,
 		g_free (template_uri);
 		g_object_unref (file);
 	}
-	
+
 	return app;
 }
+
+/* Application */
+
+G_DEFINE_TYPE (Anjuta, anjuta, GTK_TYPE_APPLICATION)
+
+static void
+anjuta_finalize (GObject *object)
+{
+  G_OBJECT_CLASS (anjuta_parent_class)->finalize (object);
+}
+
+static void
+anjuta_open (GApplication *application,
+			 GFile **files,
+			 gint n_files,
+			 const gchar* hint)
+{
+	int i;
+	GList* windows = gtk_application_get_windows (GTK_APPLICATION (application));
+	AnjutaApp *app = ANJUTA_APP (windows->data);
+	IAnjutaFileLoader* loader =
+		anjuta_shell_get_interface(ANJUTA_SHELL(app), IAnjutaFileLoader, NULL);
+	
+	if (!loader)
+		return;
+		
+	for (i = 0; i < n_files; i++)
+	{
+		ianjuta_file_loader_load(loader, files[i], FALSE, NULL);
+	}
+}
+
+static void
+anjuta_activate (GApplication *application)
+{
+	/* Show first window */
+	GList* windows = gtk_application_get_windows (GTK_APPLICATION (application));
+	
+	gtk_window_present (GTK_WINDOW (windows->data));
+}
+
+static void
+anjuta_init (Anjuta *anjuta)
+{
+
+}
+
+static void
+anjuta_class_init (AnjutaClass *klass)
+{
+	GObjectClass* object_class = G_OBJECT_CLASS (klass);
+	GApplicationClass* app_class = G_APPLICATION_CLASS (klass);
+
+	object_class->finalize = anjuta_finalize;
+
+	app_class->open = anjuta_open;
+	app_class->activate = anjuta_activate;
+}
+
+Anjuta*
+anjuta_new (void)
+{
+  g_type_init ();
+
+  return g_object_new (anjuta_get_type (),
+                       "application-id", "org.gnome.anjuta",
+                       "flags", G_APPLICATION_HANDLES_OPEN,
+                       NULL);
+}
+
+/* End */
+
